@@ -22,6 +22,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <glib/gi18n.h>
 #include <glib-object.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
@@ -116,9 +117,8 @@ static void popup_error_dialog (AccessxStatusApplet        *sapplet);
 
 /* cribbed from geyes */
 static void
-about_cb (BonoboUIComponent          *uic,
-	  AccessxStatusApplet        *sapplet,
-	  const gchar                *verbname)
+about_cb (GtkAction           *action,
+	  AccessxStatusApplet *sapplet)
 {
         static const gchar *authors [] = {
 		"Calum Benson <calum.benson@sun.com>",
@@ -145,9 +145,8 @@ about_cb (BonoboUIComponent          *uic,
 }
 
 static void
-help_cb (BonoboUIComponent   *uic,
-	 AccessxStatusApplet *sapplet,
-	 const char          *verbname)
+help_cb (GtkAction           *action,
+	 AccessxStatusApplet *sapplet)
 {
 	GError *error = NULL;
 
@@ -182,9 +181,8 @@ help_cb (BonoboUIComponent   *uic,
 }
 
 static void
-dialog_cb (BonoboUIComponent *component,
-	   AccessxStatusApplet *sapplet,
-	   const char        *verb)
+dialog_cb (GtkAction           *action,
+	   AccessxStatusApplet *sapplet)
 {
 	GError *error = NULL;
 
@@ -231,12 +229,16 @@ dialog_cb (BonoboUIComponent *component,
 	}
 }
 
-static const BonoboUIVerb accessx_status_applet_menu_verbs [] = {
-	BONOBO_UI_UNSAFE_VERB ("Dialog", dialog_cb),
-	BONOBO_UI_UNSAFE_VERB ("Help", help_cb),
-	BONOBO_UI_UNSAFE_VERB ("About", about_cb),
-
-	BONOBO_UI_VERB_END
+static const GtkActionEntry accessx_status_applet_menu_actions [] = {
+	{ "Dialog", GTK_STOCK_PROPERTIES, N_("_Keyboard Accessibility Preferences"),
+	  NULL, NULL,
+	  G_CALLBACK (dialog_cb) },
+	{ "Help", GTK_STOCK_HELP, N_("_Help"),
+	  NULL, NULL,
+	  G_CALLBACK (help_cb) },
+	{ "About", GTK_STOCK_ABOUT, N_("_About"),
+	  NULL, NULL,
+	  G_CALLBACK (about_cb) }
 };
 
 static XkbDescPtr 
@@ -272,8 +274,11 @@ accessx_status_applet_xkb_select (AccessxStatusApplet *sapplet)
 	int opcode_rtn, error_rtn;
 	gboolean retval = FALSE;
 	Display *display = NULL;
-	g_assert (sapplet && sapplet->applet && GTK_WIDGET (sapplet->applet)->window);
-	display = GDK_WINDOW_XDISPLAY (GTK_WIDGET (sapplet->applet)->window);
+        GdkWindow *window;
+
+        window = gtk_widget_get_window (GTK_WIDGET (sapplet->applet));
+	g_assert (sapplet && sapplet->applet && window);
+	display = GDK_WINDOW_XDISPLAY (window);
 	g_assert (display);
 	retval = XkbQueryExtension (display, &opcode_rtn, &xkb_base_event_type, 
 				    &error_rtn, NULL, NULL);
@@ -424,6 +429,7 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 				      XkbAccessXNotifyEvent *event)
 {
 	GdkPixbuf *ret_pixbuf;
+	GdkWindow *window;
 	gboolean is_idle = TRUE;
 	gchar *stock_id = SLOWKEYS_IDLE_ICON;
 	GtkStyle *style = gtk_widget_get_style (GTK_WIDGET (sapplet->applet));
@@ -470,9 +476,11 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 		ret_pixbuf = gdk_pixbuf_copy (tmp_pixbuf);
 		g_object_unref (tmp_pixbuf);
 
-		if (event && GTK_WIDGET (sapplet->applet)->window) {
+		window = gtk_widget_get_window (GTK_WIDGET (sapplet->applet));
+
+		if (event && window) {
 			KeySym keysym = XKeycodeToKeysym (
-				GDK_WINDOW_XDISPLAY (GTK_WIDGET (sapplet->applet)->window),
+				GDK_WINDOW_XDISPLAY (window),
 				event->keycode, 
 				0); 
 			glyphstring = XKeysymToString (keysym);
@@ -480,7 +488,7 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 			    (g_utf8_strlen (glyphstring, -1) > 1))
 				glyphstring = "";
 		}
-		fg = style->fg[GTK_WIDGET_STATE (sapplet->applet)];
+		fg = style->fg[gtk_widget_get_state (GTK_WIDGET (sapplet->applet))];
 		glyph_pixbuf = accessx_status_applet_get_glyph_pixbuf (sapplet, 
 								       GTK_WIDGET (sapplet->applet),
 								       ret_pixbuf, 
@@ -508,7 +516,7 @@ accessx_status_applet_bouncekeys_image (AccessxStatusApplet *sapplet, XkbAccessX
 
 	g_assert (sapplet->applet);
 	style = gtk_widget_get_style (GTK_WIDGET (sapplet->applet));
-	fg = style->text[GTK_WIDGET_STATE (GTK_WIDGET (sapplet->applet))];
+	fg = style->text[gtk_widget_get_state (GTK_WIDGET (sapplet->applet))];
 	bg = style->base[GTK_STATE_NORMAL];
 
 	if (event != NULL) {
@@ -612,16 +620,20 @@ accessx_status_applet_update (AccessxStatusApplet *sapplet,
 			      AccessxStatusNotifyType notify_type,
 			      XkbEvent *event)
 {
+	GtkWindow * window;
 	gint i;
+
+	window = gtk_widget_get_window (GTK_WIDGET (sapplet->applet));
+
 	if (notify_type & ACCESSX_STATUS_MODIFIERS) {
 		unsigned int locked_mods = 0, latched_mods = 0;
 		if (event != NULL) {
 			locked_mods = event->state.locked_mods;
 			latched_mods = event->state.latched_mods;
 		}
-		else if (sapplet->applet && GTK_WIDGET (sapplet->applet)->window) {
+		else if (sapplet->applet && window) {
 			XkbStateRec state;			
-			XkbGetState (GDK_WINDOW_XDISPLAY (GTK_WIDGET (sapplet->applet)->window), 
+			XkbGetState (GDK_WINDOW_XDISPLAY (window), 
 				     XkbUseCoreKbd, &state); 
 			locked_mods = state.locked_mods;
 			latched_mods = state.latched_mods;
@@ -664,7 +676,7 @@ accessx_status_applet_update (AccessxStatusApplet *sapplet,
 
 	if (notify_type & ACCESSX_STATUS_ENABLED) {
 		/* Update the visibility of widgets in the box */
-		XkbGetControls (GDK_WINDOW_XDISPLAY (GTK_WIDGET (sapplet->applet)->window), 
+		XkbGetControls (GDK_WINDOW_XDISPLAY (window), 
 				/* XkbMouseKeysMask | XkbStickyKeysMask | 
 				   XkbSlowKeysMask | XkbBounceKeysMask, */
 				XkbAllControlsMask,
@@ -933,9 +945,9 @@ static void
 accessx_status_applet_reparent_widget (GtkWidget *widget, GtkContainer *container) 
 {
 	if (widget) {
-		if (widget->parent) {
+		if (gtk_widget_get_parent (widget)) {
 			g_object_ref (G_OBJECT (widget));
-			gtk_container_remove (GTK_CONTAINER (widget->parent), widget);
+			gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (widget)), widget);
 		}
 		gtk_container_add (container, widget);
 	}
@@ -977,7 +989,8 @@ accessx_status_applet_layout_box (AccessxStatusApplet *sapplet, GtkWidget *box,
 
 	gtk_widget_show (sapplet->box);
 	gtk_widget_show (GTK_WIDGET (sapplet->applet));
-	if (GTK_WIDGET_REALIZED (sapplet->box) &&
+
+	if (gtk_widget_get_realized (sapplet->box) &&
             sapplet->initialized)
 		accessx_status_applet_update (sapplet, ACCESSX_STATUS_ALL, NULL);
 }
@@ -1185,7 +1198,7 @@ accessx_status_applet_background (PanelApplet *a,
 
                 case PANEL_PIXMAP_BACKGROUND:
                         style = gtk_style_copy (
-                                        GTK_WIDGET (sapplet->applet)->style);
+                                        gtk_widget_get_style (GTK_WIDGET (sapplet->applet)));
                         if (style->bg_pixmap[GTK_STATE_NORMAL])
                                 g_object_unref
                                         (style->bg_pixmap[GTK_STATE_NORMAL]);
@@ -1206,7 +1219,7 @@ static gboolean
 button_press_cb (GtkWidget *widget, GdkEventButton *event, AccessxStatusApplet *sapplet)
 {
 	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) 
-		dialog_cb (NULL, sapplet, NULL);
+		dialog_cb (NULL, sapplet);
 
 	return FALSE;
 }
@@ -1221,7 +1234,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, AccessxStatusApplet *sapple
 	case GDK_Return:
 	case GDK_space:
 	case GDK_KP_Space:
-		dialog_cb (NULL, sapplet, NULL);
+		dialog_cb (NULL, sapplet);
 		return TRUE;
 
 	default:
@@ -1276,11 +1289,13 @@ accessx_status_applet_fill (PanelApplet *applet)
 {
 	AccessxStatusApplet *sapplet;
 	AtkObject           *atk_object;
+	GtkActionGroup      *action_group;
+	gchar               *ui_path;
 	gboolean was_realized = FALSE;
 
 	sapplet = create_applet (applet);
 
-	if (!GTK_WIDGET_REALIZED (sapplet->box)) {
+	if (!gtk_widget_get_realized (sapplet->box)) {
 		g_signal_connect_after (G_OBJECT (sapplet->box), 
 					"realize", G_CALLBACK (accessx_status_applet_realize), 
 					sapplet);
@@ -1301,23 +1316,23 @@ accessx_status_applet_fill (PanelApplet *applet)
 	g_signal_connect (sapplet->applet, "key_press_event",
 				   G_CALLBACK (key_press_cb), sapplet);				   
 
-	panel_applet_setup_menu_from_file (sapplet->applet,
-                                           DATADIR,
-				           "GNOME_AccessxApplet.xml",
-                                           NULL,
-				           accessx_status_applet_menu_verbs,
-				           sapplet);
+	action_group = gtk_action_group_new ("Accessx Applet Actions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (action_group,
+				      accessx_status_applet_menu_actions,
+				      G_N_ELEMENTS (accessx_status_applet_menu_actions),
+				      sapplet);
+	ui_path = g_build_filename (ACCESSX_MENU_UI_DIR, "accessx-status-applet-menu.xml", NULL);
+	panel_applet_setup_menu_from_file (sapplet->applet, ui_path, action_group);
+	g_free (ui_path);
 
 	if (panel_applet_get_locked_down (sapplet->applet)) {
-		BonoboUIComponent *popup_component;
+		GtkAction *action;
 
-		popup_component = panel_applet_get_popup_component (sapplet->applet);
-
-		bonobo_ui_component_set_prop (popup_component,
-					      "/commands/Dialog",
-					      "hidden", "1",
-					      NULL);
+		action = gtk_action_group_get_action (action_group, "Dialog");
+		gtk_action_set_visible (action, FALSE);
 	}
+	g_object_unref (action_group);
 
 	gtk_widget_set_tooltip_text (GTK_WIDGET (sapplet->applet), _("Keyboard Accessibility Status"));
 
@@ -1339,14 +1354,13 @@ accessx_status_applet_factory (PanelApplet *applet,
 			       gpointer     data)
 {
 	gboolean retval = FALSE;
-	if (!strcmp (iid, "OAFIID:GNOME_AccessxStatusApplet"))
+	if (!strcmp (iid, "AccessxStatusApplet"))
 		retval = accessx_status_applet_fill (applet);
 	return retval;
 }
 
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_AccessxStatusApplet_Factory",
-			     PANEL_TYPE_APPLET,
-			     "accessx-status",
-			     "0",
-			     accessx_status_applet_factory,
-			     NULL)
+PANEL_APPLET_OUT_PROCESS_FACTORY ("AccessxStatusAppletFactory",
+				  PANEL_TYPE_APPLET,
+				  "accessx-status",
+				  accessx_status_applet_factory,
+				  NULL)
