@@ -19,7 +19,7 @@
 
 #include <config.h>
 #include <math.h>
-#include <gnome.h>
+#include <stdlib.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 #include "geyes.h"
@@ -41,7 +41,7 @@ applet_back_change (PanelApplet			*a,
         gtk_widget_set_style (GTK_WIDGET (eyes_applet->applet), NULL);
         rc_style = gtk_rc_style_new ();
         gtk_widget_modify_style (GTK_WIDGET (eyes_applet->applet), rc_style);
-        gtk_rc_style_unref (rc_style);
+        g_object_unref (rc_style);
 
         switch (type) {
                 case PANEL_COLOR_BACKGROUND:
@@ -50,8 +50,8 @@ applet_back_change (PanelApplet			*a,
                         break;
 
                 case PANEL_PIXMAP_BACKGROUND:
-                        style = gtk_style_copy (GTK_WIDGET (
-						eyes_applet->applet)->style);
+                        style = gtk_style_copy (gtk_widget_get_style (GTK_WIDGET (
+						eyes_applet->applet)));
                         if (style->bg_pixmap[GTK_STATE_NORMAL])
                                 g_object_unref
                                         (style->bg_pixmap[GTK_STATE_NORMAL]);
@@ -75,6 +75,7 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
 		    gint x, gint y,
 		    gint *pupil_x, gint *pupil_y, GtkWidget* widget)
 {
+        GtkAllocation allocation;
         double sina;
         double cosa;
         double h;
@@ -84,8 +85,9 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
 	 gfloat xalign, yalign;
 	 gint width, height;
 
-	 width = GTK_WIDGET(widget)->allocation.width;
-	 height = GTK_WIDGET(widget)->allocation.height;
+	 gtk_widget_get_allocation (GTK_WIDGET(widget), &allocation);
+	 width = allocation.width;
+	 height = allocation.height;
 	 gtk_misc_get_alignment(GTK_MISC(widget),  &xalign, &yalign);
 
 	 nx = x - MAX(width - eyes_applet->eye_width, 0) * xalign - eyes_applet->eye_width / 2;
@@ -152,7 +154,7 @@ timer_cb (EyesApplet *eyes_applet)
         gint i;
 
         for (i = 0; i < eyes_applet->num_eyes; i++) {
-		if (GTK_WIDGET_REALIZED (eyes_applet->eyes[i])) {
+		if (gtk_widget_get_realized (eyes_applet->eyes[i])) {
 			gtk_widget_get_pointer (eyes_applet->eyes[i], 
 						&x, &y);
 			if ((x != eyes_applet->pointer_last_x[i]) || (y != eyes_applet->pointer_last_y[i])) { 
@@ -169,9 +171,8 @@ timer_cb (EyesApplet *eyes_applet)
 }
 
 static void
-about_cb (BonoboUIComponent *uic,
-	  EyesApplet        *eyes_applet,
-	  const gchar       *verbname)
+about_cb (GtkAction   *action,
+	  EyesApplet  *eyes_applet)
 {
         static const gchar *authors [] = {
 		"Dave Camp <campd@oit.edu>",
@@ -300,7 +301,7 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 {
 	g_return_if_fail (eyes_applet);
 
-	gtk_timeout_remove (eyes_applet->timeout_id);
+	g_source_remove (eyes_applet->timeout_id);
 	if (eyes_applet->hbox)
 		destroy_eyes (eyes_applet);
 	eyes_applet->timeout_id = 0;
@@ -330,15 +331,14 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 }
 
 static void
-help_cb (BonoboUIComponent *uic,
-	 EyesApplet        *eyes_applet,
-	 const char        *verbname)
+help_cb (GtkAction  *action,
+	 EyesApplet *eyes_applet)
 {
 	GError *error = NULL;
 
-	gnome_help_display_on_screen (
-		"geyes", NULL,
-		gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
+		"ghelp:geyes",
+		gtk_get_current_event_time (),
 		&error);
 
 	if (error) {
@@ -354,12 +354,16 @@ help_cb (BonoboUIComponent *uic,
 }
 
 
-static const BonoboUIVerb geyes_applet_menu_verbs [] = {
-        BONOBO_UI_UNSAFE_VERB ("Props", properties_cb),
-        BONOBO_UI_UNSAFE_VERB ("Help", help_cb),
-        BONOBO_UI_UNSAFE_VERB ("About", about_cb),
-
-        BONOBO_UI_VERB_END
+static const GtkActionEntry geyes_applet_menu_actions [] = {
+	{ "Props", GTK_STOCK_PROPERTIES, N_("_Preferences"),
+	  NULL, NULL,
+	  G_CALLBACK (properties_cb) },
+	{ "Help", GTK_STOCK_HELP, N_("_Help"),
+	  NULL, NULL,
+	  G_CALLBACK (help_cb) },
+	{ "About", GTK_STOCK_ABOUT, N_("_About"),
+	  NULL, NULL,
+	  G_CALLBACK (about_cb) }
 };
 
 static void
@@ -381,6 +385,8 @@ static gboolean
 geyes_applet_fill (PanelApplet *applet)
 {
 	EyesApplet *eyes_applet;
+	GtkActionGroup *action_group;
+	gchar *ui_path;
 
 	g_set_application_name (_("Eyes"));
 	
@@ -391,26 +397,27 @@ geyes_applet_fill (PanelApplet *applet)
 
 	panel_applet_add_preferences (applet, "/schemas/apps/geyes/prefs", NULL);
 
-        eyes_applet->timeout_id = gtk_timeout_add (
+        eyes_applet->timeout_id = g_timeout_add (
 		UPDATE_TIMEOUT, (GtkFunction) timer_cb, eyes_applet);
-			
+
+	action_group = gtk_action_group_new ("Geyes Applet Actions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (action_group,
+				      geyes_applet_menu_actions,
+				      G_N_ELEMENTS (geyes_applet_menu_actions),
+				      eyes_applet);
+	ui_path = g_build_filename (GEYES_MENU_UI_DIR, "geyes-applet-menu.xml", NULL);
 	panel_applet_setup_menu_from_file (eyes_applet->applet,
-                                           DATADIR,
-				           "GNOME_GeyesApplet.xml",
-                                           NULL,
-				           geyes_applet_menu_verbs,
-				           eyes_applet);
+					   ui_path, action_group);
+	g_free (ui_path);
 
 	if (panel_applet_get_locked_down (eyes_applet->applet)) {
-		BonoboUIComponent *popup_component;
+		GtkAction *action;
 
-		popup_component = panel_applet_get_popup_component (eyes_applet->applet);
-
-		bonobo_ui_component_set_prop (popup_component,
-					      "/commands/Props",
-					      "hidden", "1",
-					      NULL);
+		action = gtk_action_group_get_action (action_group, "Props");
+		gtk_action_set_visible (action, FALSE);
 	}
+	g_object_unref (action_group);
 
 	gtk_widget_set_tooltip_text (GTK_WIDGET (eyes_applet->applet), _("Eyes"));
 
@@ -448,7 +455,7 @@ geyes_applet_factory (PanelApplet *applet,
 
 	theme_dirs_create ();
 
-	if (!strcmp (iid, "OAFIID:GNOME_GeyesApplet"))
+	if (!strcmp (iid, "GeyesApplet"))
 		retval = geyes_applet_fill (applet); 
    
 	if (retval == FALSE) {
@@ -458,9 +465,8 @@ geyes_applet_factory (PanelApplet *applet,
 	return retval;
 }
 
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_GeyesApplet_Factory",
-			     PANEL_TYPE_APPLET,
-			     "geyes",
-			     "0",
-			     geyes_applet_factory,
-			     NULL)
+PANEL_APPLET_OUT_PROCESS_FACTORY ("GeyesAppletFactory",
+				  PANEL_TYPE_APPLET,
+				  "geyes",
+				  geyes_applet_factory,
+				  NULL)
