@@ -816,7 +816,7 @@ gweather_pref_create (GWeatherPref *pref)
     gtk_window_set_screen (GTK_WINDOW (pref),
 			   gtk_widget_get_screen (GTK_WIDGET (pref->priv->applet->applet)));
 
-    pref_vbox = GTK_DIALOG (pref)->vbox;
+    pref_vbox = gtk_dialog_get_content_area (GTK_DIALOG (pref));
     gtk_box_set_spacing (GTK_BOX (pref_vbox), 2);
     gtk_widget_show (pref_vbox);
 
