@@ -24,16 +24,14 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-desktop-item.h> 
-#include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
 #include "global.h"
 
 static void
-about_cb (BonoboUIComponent *uic,
-	  MultiloadApplet   *ma,
-	  const char        *name)
+about_cb (GtkAction       *action,
+	  MultiloadApplet *ma)
 {
     const gchar * const authors[] =
     {
@@ -66,18 +64,17 @@ about_cb (BonoboUIComponent *uic,
 }
 
 static void
-help_cb (BonoboUIComponent *uic,
-	  MultiloadApplet   *ma,
-	  const char        *name)
+help_cb (GtkAction       *action,
+	 MultiloadApplet *ma)
 {
 
  	GError *error = NULL;
                                                                                 
-    	gnome_help_display_on_screen (
-                "multiload", NULL,
-                gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
-                &error);
-                                                                                
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
+			"ghelp:multiload",
+			gtk_get_current_event_time (),
+			&error);
+
     	if (error) { /* FIXME: the user needs to see this */
         	g_warning ("help error: %s\n", error->message);
         	g_error_free (error);
@@ -143,9 +140,8 @@ start_procman (MultiloadApplet *ma)
 }
               
 static void
-start_procman_cb (BonoboUIComponent *uic,
-		  MultiloadApplet   *ma,
-		  const char        *name)
+start_procman_cb (GtkAction       *action,
+		  MultiloadApplet *ma)
 {
 	start_procman (ma);
 }
@@ -202,39 +198,6 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 	return;
 }
 
-static gboolean
-multiload_enter_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
-{
-	MultiloadApplet *ma;
-	gint i;
-
-	ma = (MultiloadApplet *)data;
-	
-	for (i = 0; i < NGRAPHS; i++)
-		if (ma->graphs[i]->visible)
-		{
-			ma->graphs[i]->tooltip_update = TRUE;
-			multiload_applet_tooltip_update(ma->graphs[i]);
-		}
-	
-	return TRUE;
-}
-
-
-static gboolean
-multiload_leave_cb(GtkWidget *widget, GdkEventCrossing *event, gpointer data)
-{
-	MultiloadApplet *ma;
-	gint i;
-
-	ma = (MultiloadApplet *)data;
-
-	for (i = 0; i < NGRAPHS; i++)
-			ma->graphs[i]->tooltip_update = FALSE;
-		
-	return TRUE;
-}
-
 
 static gboolean
 multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MultiloadApplet *ma)
@@ -300,9 +263,6 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	else
 		g_assert_not_reached();
 	
-	/* fill data[0] with the current load */
-	g->get_data (g->draw_height, g->data[0], g);
-	
 	if (!strncmp(g->name, "memload", strlen("memload"))) {
 		guint mem_user, mem_cache, user_percent, cache_percent;
 		mem_user  = g->data[0][0];
@@ -326,6 +286,17 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		tooltip_text = g_strdup_printf(_("The system load average is %0.02f"),
 					       g->loadavg1);
 
+	} else if (!strcmp(g->name, "netload2")) {
+		char *tx_in, *tx_out;
+		tx_in = netspeed_get(g->netspeed_in);
+		tx_out = netspeed_get(g->netspeed_out);
+		/* xgettext: same as in graphic tab of g-s-m */
+		tooltip_text = g_strdup_printf(_("%s:\n"
+						 "Receiving %s\n"
+						 "Sending %s"),
+					       name, tx_in, tx_out);
+		g_free(tx_in);
+		g_free(tx_out);
 	} else {
 		const char *msg;
 		guint i, total_used, percent;
@@ -458,13 +429,19 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	return;
 }
 
-static const BonoboUIVerb multiload_menu_verbs [] = {
-	BONOBO_UI_UNSAFE_VERB ("MultiLoadProperties", multiload_properties_cb),
-	BONOBO_UI_UNSAFE_VERB ("MultiLoadRunProcman", start_procman_cb),
-	BONOBO_UI_UNSAFE_VERB ("MultiLoadHelp", help_cb),
-	BONOBO_UI_UNSAFE_VERB ("MultiLoadAbout", about_cb),
-
-	BONOBO_UI_VERB_END
+static const GtkActionEntry multiload_menu_actions [] = {
+	{ "MultiLoadProperties", GTK_STOCK_PROPERTIES, N_("_Preferences"),
+	  NULL, NULL,
+	  G_CALLBACK (multiload_properties_cb) },
+	{ "MultiLoadRunProcman", GTK_STOCK_EXECUTE, N_("_Open System Monitor"),
+	  NULL, NULL,
+	  G_CALLBACK (start_procman_cb) },
+	{ "MultiLoadHelp", GTK_STOCK_HELP, N_("_Help"),
+	  NULL, NULL,
+	  G_CALLBACK (help_cb) },
+	{ "MultiLoadAbout", GTK_STOCK_ABOUT, N_("_About"),
+	  NULL, NULL,
+	  G_CALLBACK (about_cb) }
 };		
 
 /* create a box and stuff the load graphs inside of it */
@@ -473,7 +450,8 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	MultiloadApplet *ma;
 	GConfClient *client;
-	BonoboUIComponent *popup_component;
+	GtkActionGroup *action_group;
+	gchar *ui_path;
 	
 	ma = g_new0(MultiloadApplet, 1);
 	
@@ -491,43 +469,43 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
-	panel_applet_setup_menu_from_file (applet,
-					   DATADIR,
-					   "GNOME_MultiloadApplet.xml",
-					   NULL,
-					   multiload_menu_verbs,
-					  ma);	
+	action_group = gtk_action_group_new ("Multiload Applet Actions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_actions (action_group,
+				      multiload_menu_actions,
+				      G_N_ELEMENTS (multiload_menu_actions),
+				      ma);
+	ui_path = g_build_filename (MULTILOAD_MENU_UI_DIR, "multiload-applet-menu.xml", NULL);
+	panel_applet_setup_menu_from_file (applet, ui_path, action_group);
+	g_free (ui_path);
 
-	popup_component = panel_applet_get_popup_component (applet);
 
 	if (panel_applet_get_locked_down (applet)) {
-		bonobo_ui_component_set_prop (popup_component,
-					      "/commands/MultiLoadProperties",
-					      "hidden", "1",
-					      NULL);
+		GtkAction *action;
+
+		action = gtk_action_group_get_action (action_group, "MultiLoadProperties");
+		gtk_action_set_visible (action, FALSE);
 	}
 
 	client = gconf_client_get_default ();
 	if (gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL) ||
 	    panel_applet_get_locked_down (applet)) {
+		GtkAction *action;
+
 		/* When the panel is locked down or when the command line is inhibited,
 		   it seems very likely that running the procman would be at least harmful */
-		bonobo_ui_component_set_prop (popup_component,
-					      "/commands/MultiLoadRunProcman",
-					      "hidden", "1",
-					      NULL);
+		action = gtk_action_group_get_action (action_group, "MultiLoadRunProcman");
+		gtk_action_set_visible (action, FALSE);
 	}
 
+	g_object_unref (action_group);
+
 	g_signal_connect(G_OBJECT(applet), "change_size",
 				G_CALLBACK(multiload_change_size_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "change_orient",
 				G_CALLBACK(multiload_change_orient_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "destroy",
 				G_CALLBACK(multiload_destroy_cb), ma);
-	g_signal_connect(G_OBJECT(applet), "enter_notify_event",
-				G_CALLBACK(multiload_enter_cb), ma);
-	g_signal_connect(G_OBJECT(applet), "leave_notify_event",
-				G_CALLBACK(multiload_leave_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "button_press_event",
 				G_CALLBACK(multiload_button_press_event_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "key_press_event",
@@ -554,9 +532,8 @@ multiload_factory (PanelApplet *applet,
 	return retval;
 }
 
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MultiLoadApplet_Factory",
-				   PANEL_TYPE_APPLET,
-				   "multiload",
-				   "0",
-				   multiload_factory,
-				   NULL)
+PANEL_APPLET_OUT_PROCESS_FACTORY ("MultiLoadAppletFactory",
+				  PANEL_TYPE_APPLET,
+				  "multiload",
+				  multiload_factory,
+				  NULL)
